Welcome to cgen's documentation!
==================================

.. module:: cgen

Contents
--------

.. toctree::
    :maxdepth: 2

    cgen
    faq

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
